<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" exclude-result-prefixes="tei"
    version="2.0">
    
    <xsl:output method="html" encoding="UTF-8"/>
    
    <!-- Vorgehen: 
                - die Ausgangsdateien in einer Variablen zusammenführen
                - Grundstruktur für synoptische Darstellung schaffen:
                    - HTML-Datei mit Kopfbereich für CSS-Angaben und Javascript
                    - mit body und div-Elementen, in denen die Texte ausgegeben werden
                - mit apply-templates die Editionstexte reinholen
                - diese mit einzelenen (Push)-Templates weiterverarbeiten
                - Faksimiles mit den Page-Breaks verlinken
                - Kommentar hinzufügen
            -->
    
    <!-- Hier werden die Ausgangsdateien, die für die synoptische Darstellung von Transkription, Übersetzung und Kommentar gebraucht werden,
    in einer Variablen zwischengespeichert (die gesamten Dokumente werden in die Variable "daten" geschrieben)-->
    <xsl:variable name="daten">
        <daten>
            <xsl:copy-of select="document('tei-transcript.xml')" />
            <xsl:copy-of select="document('tei-translation.xml')" />
            <xsl:copy-of select="document('tei-comment.xml')" />
        </daten>
    </xsl:variable> 
    
    <!-- Wurzeltemplate: hier wird ein HTML-Dokument aufgebaut -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Amoenitates Exoticae</title>
                <!-- Javascript-Bereich; die Funktion "toggle" dient dazu, Kommentare ein- und auszublenden -->
                <script type="text/javascript">
                     function toggle(ID){
                        var el = document.getElementById(ID);
                        if (el.style.display == "block"){
                            el.style.display = "none";
                        }
                        else {
                            el.style.display = "block";
                        }
                    };
                </script>
                <!-- CSS-Bereich mit Angaben zur Formatierung bestimmter Elementtypen (z.B. Überschriften: h1) oder Klassen (z.B. Elemente mit 
                    einem class-Attribut 'capital') -->
                <style type="text/css">
                    .wrapper {
                        width: 1000px;
                        clear: both;
                    }
                    .transcript {
                        width: 45%;
                        float: left;
                        border: 1px solid black;
                        padding: 10px;
                    }
                    .translation {
                        width: 45%;
                        float: right;
                        border: 1px solid black;
                        padding: 10px;
                    }
                    h1 {
                        font-size: 12pt;
                    }
                    .capital  {
                        font-variant: small-caps;
                    }
                    .pb, .marginalie {
                        color: #0033FF;
                    }
                    .marginalie {
                        display: block;
                        padding: 10px 0px;
                    }
                    .abbr, .place {
                        color: #CC00FF;
                    }
                    .kommentarLink {
                        color: #FF00B3;
                        cursor: pointer;
                        position: relative;
                    }
                    .kommentar {
                        position: absolute;
                        width: 400px;
                        background-color: white;
                        border: 1px solid black;
                        padding: 5px;
                        z-index: 500;
                    }
                </style>
            </head>
            <body>
              <!-- ein Blockelement (<div>), das den gesamten Inhaltsbereich umschließt -->
               <div class="wrapper">
                    <!-- Bereich für die Transkription -->
                    <div class="transcript">
                        <!-- hier sollen weitere Schablonen berücksichtigt werden und zwar für den Teilbaum <div xml:id='AEl-1.1'>...</div> aus dem 
                        Ausgangsdokument (das erste Teilkapitel, lateinischer Text) -->
                        <xsl:apply-templates select="$daten//tei:div[@xml:id = 'AEl-1.1']" />
                    </div>
                   <!-- Bereich für die Übersetzung -->
                    <div class="translation">
                        <!-- hier sollen ebenfalls weitere Schablonen berücksichtigt werden und zwar für den Teilbaum <div xml:id='AEd-1.1'>...</div> aus dem 
                        Ausgangsdokument (das erste Teilkapitel, deutsche Übersetzung) -->
                        <xsl:apply-templates select="$daten//tei:div[@xml:id = 'AEd-1.1']" />
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <!-- ################################## weitere (Push-Schablonen) #########################################################
    dies sind die weiteren Schablonen, die bei der Transformation berücksichtigt werden; immer, wenn der Prozessor auf die in den 
    match-Attributen angegebenen Elemente stößt, werden die entsprechenden Schablonen angewandt
    -->
    
    
    <!-- ein Template für Überschriften -->
    <xsl:template match="tei:head">
        <!-- aus <head>-Elementen im Ausgangsdokument werden <h1>-Elemente im Zieldokument -->
        <h1>
            <!-- es sollen weitere Schablonen berücksichtigt werden (d.h., dass mindestens der Text innerhalb des Überschriftenelements ausgegeben wird!
                denn für Text gibt es eine Standardschablone, mit der der Textinhalt von Elementen immer ausgegeben wird, falls nichts Anderes gesagt ist) -->
            <xsl:apply-templates />
        </h1>
    </xsl:template>
    
    <!-- <emph>-Elemente ohne rendition-Attribut werden als <em> (im Browser kursiv) ausgegeben -->
    <xsl:template match="tei:emph[not(@rendition)]">
        <em>
            <xsl:apply-templates />
        </em>
    </xsl:template>
    
    <!-- Kapitälchen -->
    <xsl:template match="tei:emph[@rendition = 'capital']">
        <span class="capital">
            <!-- Formatierungen für Elemente mit der Klasse "capital" sind oben im CSS-Bereich der HTML-Datei angegeben -->
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <!-- Seitenumbrüche -->
    <xsl:template match="tei:pb">
        <!-- im Ausgangs-TEI-Dokument verweisen die Seitenumbruch-Elemente auf die ID des jeweiligen Faksimiles:
        z.B. <pb facs="#xyz" />
        an anderer Stelle im Dokument gibt es <graphic>-Elemente mit der Faksimile-ID (@xml:id)
        und mit einem url-Attribut, in dem die URL des Faksimiles angegeben ist
        wir bilden eine Variable, die diese URL holt -->
        <xsl:variable name="facsURL" select="//tei:graphic[@xml:id = substring-after(current()/@facs, '#')]/@url" />
        <!-- "gehe zu dem graphic-Element, dessen ID der ID entspricht, die im aktuellen <pb>-Element im Attribut @facs nach dem #-Zeichen angegeben ist" 
            "gehe von dort aus weiter zum Attribut @url" -->
        <span class="pb">
            [<a href="{$facsURL}"><xsl:value-of select="@n" /></a>]
            <!-- hier wird ein HTML-Link gebaut (<a>), bei dem im Attribut href die Faksimile-URL angegeben wird und als Inhalt des Links die Seitenzahl
            (das Attribut n des <pb>-Elements) -->
        </span>
    </xsl:template>
    
    <!-- Marginalien -->
    <xsl:template match="tei:note[@place = 'margin']">
        <span class="marginalie" title="Marginalie">
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <!-- Abkürzungen -->
    <xsl:template match="tei:abbr">
        <span class="abbr">
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <!-- Ortsreferenzen -->
    <xsl:template match="tei:rs[@type = 'place']">
        <span class="place">
            <xsl:apply-templates />
        </span>
    </xsl:template>
    
    <!-- Schablone für Kommentare 
        - in der Ausgangsdatei tei-translation.xml (= Übersetzung) gibt es Pointer, die auf Kommentare verweisen, die an der Stelle des Pointers eingebunden werden sollen
        z.B. <ptr target="#AEdPreN-0.13" type="link_internal_commentary"/> 
        - im Attribut target steht die ID des Kommentars
        - Kommentare sind im Ausgangsdokument tei-comment.xml <note>-Elemente
    -->
    <xsl:template match="tei:ptr[@type = 'link_internal_commentary']">
        <!-- Variable, in der die ID des Kommentars abgelegt wird -->
        <xsl:variable name="kommentarID" select="substring-after(@target, '#')" />
        
        <!-- Stellen, an denen es Kommentare gibt, sollen im Text mit [K] markiert werden.
            - wenn man darauf klickt, wird die Javascript-Funktion "toggle" aufgerufen (siehe oben im HTML-Kopfbereich), 
            die die Kommenare ein- und ausblendet
            - der Funktion wird die ID des aktuellen Kommentars (aus der Variablen) übergeben, damit der richtige
            Kommentar (und nur dieser eine) ein-/ausgeblendet wird
        -->
        <span class="kommentarLink" onclick="toggle('{$kommentarID}');">[K]
            <!-- normalerweise wird dieser Kommentar nicht angezeigt: style="display: none;"
                (erst, wenn darauf geklickt wird)
            -->
            <span class="kommentar" id="{$kommentarID}" style="display: none;">
                <!-- hier wird gesagt, dass weitere Schablonen für den Kommentar berücksichtigt werden sollen
                - also für das <note>-Element, das die Kommentar-ID hat (auf die vom Pointer verwiesen wird) 
                - die weiteren Schablonen sind in diesem Fall: die Standardtextschablone! also wird der Text des 
                Kommentars hier ausgegeben -->
                <xsl:apply-templates select="$daten//tei:note[@xml:id = $kommentarID]" />
            </span>
        </span>
    </xsl:template>
    
    <!-- Terme werden hervorgehoben (im Browser fett dargestellt) -->
    <xsl:template match="tei:term">
        <strong>
            <xsl:apply-templates />
        </strong>
    </xsl:template>
    
</xsl:stylesheet>